@@ -89,7 +89,7 @@ class TokenAuthorization(Authorization):
 
         try:
             return re.match(
-                r'^Bearer (?P<token>\w+)$', header
+                r'^Bearer (?P<token>.+)$', header
             ).group('token')
         except TypeError:
             raise UnAuthorized('Missing authorization header')
@@ -103,7 +103,6 @@ class TokenAuthorization(Authorization):
         Raises an Unauthorized error if no bearer token is supplied in the
         request.
         """
-
         # Cache token retrieval in request context
         if '_flask_json_resource_token' in g:
             return g._flask_json_resource_token
